@@ -1,20 +1,27 @@
 # -*- coding: utf-8 -*-
-"""
-Created on Thu Mar 18 09:51:25 2021
+'''
+pyplr.plr
+=========
 
-@author: engs2242
-"""
+Tools for designing pupillometry protocols.
 
+@author: jtm
+
+'''
+
+import sys
+if sys.platform.startswith('win'):
+    from winsound import Beep
+    import tkinter as tk
+    from tkinter import simpledialog
+    
 import os
 import os.path as op
+from time import sleep
 from subprocess import Popen
 
-import tkinter as tk
-from tkinter import simpledialog
-
 def input_subject_id():
-    subject_id = input('Please enter subject ID: ')
-    return subject_id
+    return input('Please enter subject ID: ')
 
 def input_subject_id_gui():
     ROOT = tk.Tk()
@@ -31,9 +38,9 @@ def subject_dir(subject_id):
 def new_record_id(subject_dir):
     recording_id = 0
     for base, dirs, files in os.walk(subject_dir):
-        if str(recording_id).zfill(3) == op.basename(base):
+        if 'rec' + str(recording_id).zfill(3) == op.basename(base):
             recording_id += 1
-    return str(recording_id).zfill(3)
+    return 'rec' + str(recording_id).zfill(3)
 
 def record_dir(subj_dir):
     record_id = new_record_id(subj_dir)
@@ -45,4 +52,17 @@ def record_dir(subj_dir):
     return rec_dir
 
 def open_folder(folder):
-    Popen(r'explorer /select,{}'.format(folder))
\ No newline at end of file
+    Popen(r'explorer /select,{}'.format(folder))
+    
+def beep_sound():
+    if sys.platform=='darwin':
+        print('\a')
+    elif sys.platform.startswith('win'):
+        Beep(440, 200)
+        
+def timer(increment=1, seconds=0, message='Waiting...'):
+    print(message)
+    while seconds > 0:
+        print(f'\t{seconds} seconds left...')
+        sleep(increment)
+        seconds -= increment
\ No newline at end of file
