@@ -18,8 +18,7 @@ import msgpack
 import zmq
 
 class PupilCore:
-    '''
-    A class to facilitate working with Pupil Core via the Network API.
+    '''Class to facilitate working with Pupil Core via the Network API.
     
     Example
     -------
@@ -30,6 +29,9 @@ class PupilCore:
     
     '''
     
+    # TODO: use this
+    eyemap = {'left': 0, 'right': 1}
+    
     def __init__(self, address='127.0.0.1', request_port='50020', 
                  pyplr_defaults=False):
         '''Initialize the connection with Pupil Core.
@@ -74,6 +76,7 @@ class PupilCore:
         self.pub_socket.connect(
             'tcp://{}:{}'.format(self.address, self.pub_port))
         
+        # TODO: just get reid of these
         # some useful defaults
         if pyplr_defaults:
             self.notify({
@@ -157,7 +160,34 @@ class PupilCore:
         self.remote.send_string(topic, flags=zmq.SNDMORE)
         payload = msgpack.dumps(notification, use_bin_type=True)
         self.remote.send(payload)
-        return self.remote.recv_string()    
+        return self.remote.recv_string()  
+    
+    def annotation_capture_plugin(self, should):
+        '''Start or stop the Annotatiob Capture plugin.
+
+        Parameters
+        ----------
+        should : str
+            Either 'start' or 'stop'.
+
+        Raises
+        ------
+        ValueError
+            If `should` not `start` or `stop`.
+
+        Returns
+        -------
+        None.
+
+        '''
+        if should not in ['start', 'stop']:
+            raise ValueError('Must specify start or stop for should.')
+        subject = '{}_plugin'.format(should)
+        return self.notify({
+            'subject': subject,
+            'name': 'Annotation_Capture',
+            'args': {}
+            })
     
     #TODO: is this correct?
     def get_corrected_pupil_time(self):
@@ -216,14 +246,20 @@ class PupilCore:
             Dictionary of detector properties.
 
         '''
-        self.broadcast_pupil_detector_properties(detector_name, eye_id)
+        self._broadcast_pupil_detector_properties(detector_name, eye_id)
         subscriber = self.subscribe_to_topic(
             topic='notify.pupil_detector.properties')
         topic, payload = self.recv_from_subscriber(subscriber)
         return payload
     
     def freeze_3d_model(self, eye_id, frozen):
-        '''Freeze or unfreeze the 3D detector model.        
+        '''Freeze or unfreeze the Pye3D pupil detector model. 
+        
+        The Pye3D pupil detector updates continuously unless the model is 
+        frozen. The updates help to account for head slippage, but can cause 
+        artefacts in the pupil data. If there is unlikely to be any slippage 
+        (e.g.., the participant is using a chinrest) then it makes sense to 
+        freeze the 3D model before presenting stimuli.
 
         Parameters
         ----------
@@ -245,15 +281,55 @@ class PupilCore:
         '''
         if eye_id not in [0, 1]:
             raise ValueError('Must specify 0 or 1 for eye_id')
+            
         if not type(frozen) == bool:
             raise TypeError('Must specify True or False for frozen')
+            
         notification = {'topic': 'notify.pupil_detector.set_properties',
                         'subject': 'pupil_detector.set_properties',
                         'values': {'is_long_term_model_frozen': frozen},
                         'eye_id': eye_id,
                         'detector_plugin_class_name': 'Pye3DPlugin'}
+        mode = 'Freezing' if frozen else 'Unfreezing'
+        print(f'> {mode} 3d model for eye {eye_id}')
         return self.notify(notification)
     
+    def check_3d_model(self, eyes=[0,1], alert=False):
+        '''Stop and ask the overseer whether the 3D model should be refit.
+        
+        The model is well-fit when the blue and red ellipses overlap as much
+        as possible for all gaze angles and when the size of the green ellipse
+        is close to that of the eye ball. Open the debug windows if in doubt.
+        
+        Parameters
+        ----------
+        eyes : list of int, optional
+            Which eyes to refit. The default is [0,1].
+
+        Returns
+        -------
+        None.
+
+        '''
+        if alert:
+            print('\a')
+        while True:
+            response = input('> Refit the 3d model? [y/n]: ')
+            if not response in ['y','n']:
+                print("> Sorry, I didn't understand that.")
+                continue
+            else:
+                break
+        if response=='y':
+            for eye in eyes:
+                self.freeze_3d_model(eye_id=eye, frozen=False)
+            print('> Ask the participant to roll their eyes')
+            input('> Press "Enter" when ready to freeze the model: ')
+            for eye in eyes:
+                self.freeze_3d_model(eye_id=eye, frozen=True)
+        else:
+            pass        
+        
     def new_annotation(self, label, custom_fields={}):
         '''Create a new `annotation <https://docs.pupil-labs.com/core/software/pupil-capture/#annotations>`_
         (a.k.a. message / event marker / whatever you want to call it). Send it
@@ -364,14 +440,14 @@ class PupilCore:
             A list of dictionaries.
 
         '''
-        print('Grabbing {} seconds of {}'.format(seconds, topic))
+        print('> Grabbing {} seconds of {}'.format(seconds, topic))
         subscriber = self.subscribe_to_topic(topic)
         data = []
         start_time = time()
         while (time() - start_time < seconds):
             target, message = self.recv_from_subscriber(subscriber)
             data.append(message)
-        print('PupilGrabber done grabbing {} seconds of {}'.format(
+        print('> PupilGrabber done grabbing {} seconds of {}'.format(
                 seconds, topic))
         return data
     
@@ -395,13 +471,11 @@ class PupilCore:
         Example
         -------
         >>> annotation = new_annotation(label='LIGHT_ON')
-        >>> threshold = 15
-        >>> timeout = 10.
         >>> p = PupilCore()
         >>> p.command('R')
         >>> sleep(2.)
-        >>> lst_future = pupil.lightstamper(annotation, threshold, timeout)
-        >>> sleep(timeout)
+        >>> lst_future = p.light_stamper(annotation, threshold=15, timeout=10)
+        >>> sleep(10)
         >>> # light stimulus here
         >>> p.command('r')
         >>> data = lst_future.result()
@@ -458,7 +532,7 @@ class PupilCore:
             infrared. The default is `'frame.world'`.        
         '''
         subscriber = self.subscribe_to_topic(topic)
-        print('Waiting for a light to stamp...')
+        print('> Waiting for a light to stamp...')
         start_time = time()
         previous_frame, _ = self.get_next_camera_frame(
             subscriber, topic)
@@ -470,7 +544,7 @@ class PupilCore:
                 return (True, timestamp)
             if timeout:
                 if (time() - start_time > timeout):
-                    print('light_stamper failed to detect a light...')
+                    print('> light_stamper failed to detect a light...')
                     return (False,)
             previous_frame = current_frame
                 
@@ -593,11 +667,11 @@ class PupilCore:
                      'min_duration': min_duration}
             }) 
         s = self.subscribe_to_topic(topic='fixation')
-        print('Waiting for a fixation...')
+        print('> Waiting for a fixation...')
         while True:
             topic, fixation = self.recv_from_subscriber(s)
             if self._fixation_in_trigger_region(fixation, trigger_region):
-                print('Valid fixation detected...')
+                print('> Valid fixation detected...')
                 return fixation
             
     def _fixation_in_trigger_region(self, fixation, 
@@ -619,7 +693,7 @@ class PupilCore:
         '''Send annotation with updated timestamp.
         
         '''
-        print('Light stamped on {} at {}'.format(
+        print('> Light stamped on {} at {}'.format(
             subscription, timestamp))
         annotation['timestamp'] = timestamp
         self.send_annotation(annotation)
